@@ -356,7 +356,7 @@ sub _get_desired_caps ( $self, $args ) {
             # '--headless', '--disable-gpu',
             # "user-data-dir=$ENV->{TEMP_DIR}"
             # 'no-sandbox',
-            args => [ 'start-maximized', 'disable-infobars', '--disable-popup-blocking', '--disable-default-apps', '--disable-web-security', "user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str, @headless, ( $args->{args} ? $args->{args}->@* : () ) ],
+            args => [ 'start-maximized', 'disable-infobars', '--disable-popup-blocking', '--disable-default-apps', '--disable-web-security', "user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str, @headless, ( $args->{args} ? $args->{args}->@* : () ), '--no-sandbox' ],
             binary => $args->{bin} // q[],
 
             #     prefs => {
